pub struct Code {
pub export_name: Option<String>,
pub lang: Lang,
pub state_imports: Vec<StateImport>,
pub dependencies: Vec<Dependency>,
pub run: String,
}Expand description
Serialization representation of the code
Fields
export_name: Option<String>lang: Langstate_imports: Vec<StateImport>dependencies: Vec<Dependency>run: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Code
impl<'de> Deserialize<'de> for Code
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Code
impl JsonSchema for Code
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Code
impl RefUnwindSafe for Code
impl Send for Code
impl Sync for Code
impl Unpin for Code
impl UnwindSafe for Code